==> magpie_log-1.0.0.tar.gz: lib/ui/log_actiion_list.dart <==
import 'package:flutter/material.dart';
import 'package:magpie_log/file/data_analysis.dart';

///查看已圈选数据列表
class MagpieActionList extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _ActionListState();
}

class _ActionListState extends State<MagpieActionList> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text('圈选配置列表（侧滑删除）'),
        ),
        body: Container(
          child: _getListView(),
        ));
  }

  ListView _getListView() => ListView.separated(
        itemCount: MagpieDataAnalysis().getListData().length,
        separatorBuilder: (context, index) {
          return Divider(
            height: 0,
          );
        },
        itemBuilder: (BuildContext context, int position) {
          return _getItem(position);
        },
      );

  Container _getItem(int position) => Container(
          child: Dismissible(
        onDismissed: (_) {
          MagpieDataAnalysis().getListData().removeAt(position);
        },
        direction: DismissDirection.endToStart,
        background: Container(
            color: Colors.deepOrange,
            child: Align(
                alignment: Alignment.centerRight,
                child: Container(
                  child: Text(
                    '删除',
                    style: TextStyle(
                      color: Colors.white,
                      fontWeight: FontWeight.bold,
                      fontSize: 14,
                    ),
                    textAlign: TextAlign.center,
                  ),
                  margin: EdgeInsets.fromLTRB(0, 0, 50, 0),
                ))),
        key: Key(MagpieDataAnalysis().getListData()[position].actionName),
        child: Padding(
          padding: EdgeInsets.fromLTRB(20, 10, 20, 10),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Text(
                '标识: ${MagpieDataAnalysis().getListData()[position].actionName}',
                textAlign: TextAlign.left,
                style: TextStyle(
                    color: Colors.deepOrange,
                    fontWeight: FontWeight.bold,
                    fontSize: 14),
              ),
              Text(
                '路由: ${MagpieDataAnalysis().getListData()[position].pagePath}',
                textAlign: TextAlign.left,
                style: TextStyle(color: Colors.orange, fontSize: 14),
              ),
              Text(
                '描述: ${MagpieDataAnalysis().getListData()[position].description}',
                textAlign: TextAlign.left,
                style: TextStyle(color: Colors.black54, fontSize: 14),
              ),
              Container(
                margin: EdgeInsets.fromLTRB(0, 0, 0, 10),
                child: Text(
                  '参数: ${MagpieDataAnalysis().getListData()[position].analysisData}',
                  textAlign: TextAlign.left,
                  style: TextStyle(color: Colors.black54, fontSize: 14),
                ),
              ),
            ],
          ),
        ),
      ));
}

==> magpie_log-1.0.1.tar.gz: lib/ui/log_actiion_list.dart <==
import 'package:flutter/material.dart';
import 'package:magpie_log/file/data_analysis.dart';

///查看已圈选数据列表
class MagpieActionList extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _ActionListState();
}

class _ActionListState extends State<MagpieActionList> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text('圈选配置列表（侧滑删除）'),
        ),
        body: Container(
          child: _getListView(),
        ));
  }

  ListView _getListView() => ListView.separated(
        itemCount: MagpieDataAnalysis.getListData().length,
        separatorBuilder: (context, index) {
          return Divider(
            height: 0,
          );
        },
        itemBuilder: (BuildContext context, int position) {
          return _getItem(position);
        },
      );

  Container _getItem(int position) => Container(
          child: Dismissible(
        onDismissed: (_) {
          MagpieDataAnalysis.getListData().removeAt(position);
        },
        direction: DismissDirection.endToStart,
        background: Container(
            color: Colors.deepOrange,
            child: Align(
                alignment: Alignment.centerRight,
                child: Container(
                  child: Text(
                    '删除',
                    style: TextStyle(
                      color: Colors.white,
                      fontWeight: FontWeight.bold,
                      fontSize: 14,
                    ),
                    textAlign: TextAlign.center,
                  ),
                  margin: EdgeInsets.fromLTRB(0, 0, 50, 0),
                ))),
        key: Key(MagpieDataAnalysis.getListData()[position].actionName),
        child: Padding(
          padding: EdgeInsets.fromLTRB(20, 10, 20, 10),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Text(
                '标识: ${MagpieDataAnalysis.getListData()[position].actionName}',
                textAlign: TextAlign.left,
                style: TextStyle(
                    color: Colors.deepOrange,
                    fontWeight: FontWeight.bold,
                    fontSize: 14),
              ),
              Text(
                '路由: ${MagpieDataAnalysis.getListData()[position].pagePath}',
                textAlign: TextAlign.left,
                style: TextStyle(color: Colors.orange, fontSize: 14),
              ),
              Text(
                '描述: ${MagpieDataAnalysis.getListData()[position].description}',
                textAlign: TextAlign.left,
                style: TextStyle(color: Colors.black54, fontSize: 14),
              ),
              Container(
                margin: EdgeInsets.fromLTRB(0, 0, 0, 10),
                child: Text(
                  '参数: ${MagpieDataAnalysis.getListData()[position].analysisData}',
                  textAlign: TextAlign.left,
                  style: TextStyle(color: Colors.black54, fontSize: 14),
                ),
              ),
            ],
          ),
        ),
      ));
}
